CREATE TABLE `company` (
    `id`                         BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `alt_company_id`             BIGINT NOT NULL DEFAULT 0,
    `company`                    VARCHAR(100) UNIQUE NOT NULL,
    `sla`                        CHAR(1) NOT NULL DEFAULT 0,
    `title`                      VARCHAR(10),
    `name`                       VARCHAR(100),
    `surname`                    VARCHAR(100),
    `address1`                   VARCHAR(100),
    `address2`                   VARCHAR(100),
    `zipcode`                    VARCHAR(20),
    `city`                       VARCHAR(100),
    `state`                      VARCHAR(100),
    `country`                    VARCHAR(100),
    `phone`                      VARCHAR(100),
    `fax`                        VARCHAR(100),
    `email`                      VARCHAR(100),
    `active`                     CHAR(1) NOT NULL DEFAULT 1,
    `max_templates`              INTEGER NOT NULL DEFAULT 1000,
    `max_hosts`                  BIGINT NOT NULL DEFAULT 10000,
    `max_services`               BIGINT NOT NULL DEFAULT 10000,
    `max_services_per_host`      SMALLINT NOT NULL DEFAULT 100,
    `max_contacts`               SMALLINT NOT NULL DEFAULT 100,
    `max_contactgroups`          SMALLINT NOT NULL DEFAULT 100,
    `max_timeperiods`            SMALLINT NOT NULL DEFAULT 1000,
    `max_timeslices_per_object`  SMALLINT NOT NULL DEFAULT 200,
    `max_groups`                 SMALLINT NOT NULL DEFAULT 100,
    `max_users`                  SMALLINT NOT NULL DEFAULT 100,
    `max_sms`                    BIGINT NOT NULL DEFAULT 10000,
    `max_dependencies_per_host`  SMALLINT NOT NULL DEFAULT 100,
    `max_downtimes_per_host`     SMALLINT NOT NULL DEFAULT 1000,
    `max_chart_views_per_user`   BIGINT NOT NULL DEFAULT 50,
    `max_charts_per_user`        BIGINT NOT NULL DEFAULT 1000,
    `max_metrics_per_chart`      SMALLINT NOT NULL DEFAULT 50,
    `max_dashboards_per_user`    SMALLINT NOT NULL DEFAULT 50,
    `max_dashlets_per_dashboard` SMALLINT NOT NULL DEFAULT 50,
    `max_hosts_in_reg_queue`     BIGINT NOT NULL DEFAULT 1000,
    `data_retention`             SMALLINT NOT NULL DEFAULT 3650,
    `sms_enabled`                CHAR(1) DEFAULT '1',
    `sms_route`                  VARCHAR(10) DEFAULT 'gold',
    `comment`                    TEXT,
    `creation_time`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `expire_time`                BIGINT NOT NULL DEFAULT 0,
    `host_reg_authkey`           VARCHAR(1000) NOT NULL DEFAULT '',
    `host_reg_enabled`           CHAR(1) NOT NULL DEFAULT '0',
    `host_reg_allow_from`        VARCHAR(300) NOT NULL DEFAULT 'all',
    `variables`                  TEXT NOT NULL
) ENGINE=InnoDB;
CREATE TABLE `user` (
    `id`                BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `company_id`        BIGINT NOT NULL DEFAULT 1,
    `username`          VARCHAR(50) UNIQUE NOT NULL,
    `name`              VARCHAR(50),
    `phone`             VARCHAR(100),
    `password_changed`  CHAR(1) NOT NULL DEFAULT 0,
    `manage_contacts`   CHAR(1) NOT NULL DEFAULT 0,
    `manage_templates`  CHAR(1) NOT NULL DEFAULT 0,
    `last_login`        BIGINT NOT NULL DEFAULT 0,
    `locked`            CHAR(1) NOT NULL DEFAULT 0,
    `role`              VARCHAR(8) NOT NULL DEFAULT 'user',
    `comment`           VARCHAR(200),
    `allow_from`        VARCHAR(300) NOT NULL DEFAULT 'all',
    `timezone`          VARCHAR(40) NOT NULL DEFAULT 'Europe/Berlin',
    `stash`             TEXT NOT NULL,
    `creation_time`     TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (`company_id`) REFERENCES `company`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `user_id_index` ON `user` (`id`);
CREATE INDEX `user_username_index` ON `user` (`username`);
CREATE TABLE `user_secret` (
    `user_id`               BIGINT NOT NULL,
    `crypt_type`            CHAR(1) DEFAULT 0,
    `salt`                  VARCHAR(128),
    `rounds`                INTEGER DEFAULT 0,
    `password`              VARCHAR(128) NOT NULL,
    `authentication_key`    VARCHAR(128),
    FOREIGN KEY (`user_id`) REFERENCES `user`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `user_secret_user_id` ON `user_secret` (`user_id`);
CREATE TABLE `session` (
    `sid`       VARCHAR(255) NOT NULL,
    `user_id`   BIGINT NOT NULL,
    `expire`    BIGINT NOT NULL,
    `stash`     TEXT,
    UNIQUE(`sid`),
    FOREIGN KEY (`user_id`) REFERENCES `user`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `session_sid_index` on `session` (`sid`);
CREATE TABLE `token` (
    `tid`       VARCHAR(255) NOT NULL,
    `sid`       VARCHAR(255) NOT NULL,
    `expire`    BIGINT NOT NULL,
    `action`    VARCHAR(100)
) ENGINE=InnoDB;
CREATE TABLE `group` (
    `id`            BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `company_id`    BIGINT NOT NULL DEFAULT 1,
    `groupname`     VARCHAR(64) NOT NULL,
    `description`   VARCHAR(100),
    `creation_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (`company_id`) REFERENCES `company`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `group_id_index` ON `group` (`id`);
CREATE INDEX `group_groupname_index` ON `group` (`groupname`);
CREATE TABLE `host_template` (
    `id`          BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `company_id`  BIGINT NOT NULL,
    `name`        VARCHAR(100) NOT NULL,
    `description` VARCHAR(100) NOT NULL DEFAULT '',
    `variables`   TEXT NOT NULL,
    `tags`        TEXT NOT NULL,
    FOREIGN KEY (`company_id`) REFERENCES `company`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `host_template_name_index` ON `host_template` (`name`);
CREATE TABLE `host` (
    `id`                    BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `company_id`            BIGINT NOT NULL DEFAULT 1,
    `hostname`              VARCHAR(100) NOT NULL,
    `ipaddr`                VARCHAR(159),
    `ipaddr6`               VARCHAR(45),
    `description`           VARCHAR(100) NOT NULL,
    `comment`               VARCHAR(100) NOT NULL DEFAULT '',
    `active_comment`        VARCHAR(400) DEFAULT 'no comment',
    `notification_comment`  VARCHAR(400) DEFAULT 'no comment',
    `facts`                 TEXT NOT NULL,
    `sysgroup`              VARCHAR(50) NOT NULL DEFAULT '',
    `sysinfo`               VARCHAR(200) NOT NULL DEFAULT '',
    `host_class`            VARCHAR(100) NOT NULL DEFAULT '',
    `system_class`          VARCHAR(100) NOT NULL DEFAULT '',
    `location_class`        VARCHAR(100) NOT NULL DEFAULT '',
    `os_class`              VARCHAR(100) NOT NULL DEFAULT '',
    `hw_class`              VARCHAR(100) NOT NULL DEFAULT '',
    `env_class`             VARCHAR(100) NOT NULL DEFAULT '',
    `active`                CHAR(1) NOT NULL DEFAULT 1,
    `allow_from`            VARCHAR(300) NOT NULL DEFAULT 'all',
    `max_sms`               INTEGER NOT NULL DEFAULT 0,
    `status`                VARCHAR(8) NOT NULL DEFAULT 'INFO',
    `status_since`          BIGINT DEFAULT 0 NOT NULL,
    `status_nok_since`      BIGINT DEFAULT 0 NOT NULL,
    `interval`              INTEGER NOT NULL DEFAULT 60,
    `retry_interval`        INTEGER NOT NULL DEFAULT 60,
    `timeout`               INTEGER NOT NULL DEFAULT 300,
    `notification_interval` INTEGER NOT NULL DEFAULT 3600,
    `notification`          CHAR(1) NOT NULL DEFAULT 1,
    `last_check`            BIGINT NOT NULL DEFAULT 0,
    `max_services`          INTEGER NOT NULL DEFAULT 0,
    `coordinates`           VARCHAR(100) DEFAULT '',
    `creation_time`         TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `variables`             TEXT NOT NULL,
    `data_retention`        SMALLINT DEFAULT 3650,
    `register`              CHAR(1) NOT NULL DEFAULT '0',
    UNIQUE(`hostname`, `company_id`),
    FOREIGN KEY (`company_id`) REFERENCES `company`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `host_id_index` ON `host` (`id`);
CREATE INDEX `host_hostname_index` ON `host` (`hostname`);
CREATE INDEX `host_company_id_index` ON `host` (`company_id`);
CREATE INDEX `host_status_since_index` ON `host` (`status_since`);
CREATE TABLE `host_secret` (
    `host_id`   BIGINT NOT NULL,
    `password`  VARCHAR(128) NOT NULL,
    FOREIGN KEY (`host_id`) REFERENCES `host`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `host_secret_host_id` ON `host_secret` (`host_id`);
CREATE TABLE `host_template_host` (
    `host_template_id`  BIGINT NOT NULL,
    `host_id`           BIGINT NOT NULL,
    UNIQUE (`host_template_id`, `host_id`),
    FOREIGN KEY (`host_template_id`) REFERENCES `host_template`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`host_id`) REFERENCES `host`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `user_group` (
    `user_id`           BIGINT NOT NULL,
    `group_id`          BIGINT NOT NULL,
    `create_service`    CHAR(1) DEFAULT 0,
    `update_service`    CHAR(1) DEFAULT 0,
    `delete_service`    CHAR(1) DEFAULT 0,
    `create_host`       CHAR(1) DEFAULT 0,
    `update_host`       CHAR(1) DEFAULT 0,
    `delete_host`       CHAR(1) DEFAULT 0,
    UNIQUE (`user_id`, `group_id`),
    FOREIGN KEY (`user_id`) REFERENCES `user`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`group_id`) REFERENCES `group`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `user_group_user_id_index` ON `user_group` (`user_id`);
CREATE INDEX `user_group_group_id_index` ON `user_group` (`group_id`);
CREATE TABLE `host_group` (
    `host_id`   BIGINT NOT NULL,
    `group_id`  BIGINT NOT NULL,
    UNIQUE (`host_id`, `group_id`),
    FOREIGN KEY (`host_id`) REFERENCES `host`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`group_id`) REFERENCES `group`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `host_group_host_id_index` ON `host_group` (`host_id`);
CREATE INDEX `host_group_group_id_index` ON `host_group` (`group_id`);
CREATE TABLE `status_priority` (
    `priority`  INTEGER NOT NULL,
    `status`    VARCHAR(10) NOT NULL
) ENGINE=InnoDB;
CREATE TABLE `plugin` (
    `id`            BIGINT NOT NULL PRIMARY KEY,
    `company_id`    BIGINT DEFAULT 1,
    `plugin`        VARCHAR(100) UNIQUE NOT NULL,
    `command`       VARCHAR(100) NOT NULL,
    `category`      VARCHAR(100) NOT NULL,
    `netaccess`     CHAR(1) NOT NULL DEFAULT '0',
    `prefer`        VARCHAR(10) NOT NULL DEFAULT 'localhost',
    `worldwide`     CHAR(1) NOT NULL DEFAULT '0',
    `subkey`        VARCHAR(20) DEFAULT 0,
    `datatype`      VARCHAR(10) NOT NULL,
    `abstract`      VARCHAR(100) NOT NULL,
    `description`   VARCHAR(500) NOT NULL,
    `info`          TEXT,
    FOREIGN KEY (`company_id`) REFERENCES `company`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `plugin_plugin_index` ON `plugin` (`plugin`);
CREATE INDEX `plugin_category_index` ON `plugin` (`category`);
CREATE TABLE `plugin_stats` (
    `plugin_id`     BIGINT NOT NULL DEFAULT 1,
    `statkey`       VARCHAR(25) NOT NULL,
    `alias`         VARCHAR(100),
    `datatype`      VARCHAR(20) NOT NULL,
    `units`         VARCHAR(20) NOT NULL DEFAULT 'default',
    `stattype`      VARCHAR(10),
    `regex`         VARCHAR(200),
    `substr`        INTEGER,
    `default`       VARCHAR(30) DEFAULT 0,
    `description`   VARCHAR(500) NOT NULL,
    FOREIGN KEY (`plugin_id`) REFERENCES `plugin`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `chart` (
    `id`        BIGINT NOT NULL PRIMARY KEY,
    `plugin_id` BIGINT NOT NULL DEFAULT 1,
    `title`     VARCHAR(100) NOT NULL,
    `options`   TEXT,
    FOREIGN KEY (`plugin_id`) REFERENCES `plugin`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `chart_title_index` ON `chart` (`title`);
CREATE TABLE `user_chart` (
    `id`          BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `user_id`     BIGINT NOT NULL DEFAULT 1,
    `public`      CHAR(1) DEFAULT 0,
    `title`       VARCHAR(50) DEFAULT 'n/a',
    `subtitle`    VARCHAR(50) NULL,
    `yaxis_label` VARCHAR(30) NULL,
    `description` VARCHAR(100) NULL,
    `options`     TEXT,
    FOREIGN KEY (`user_id`) REFERENCES `user`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `user_chart_title_index` ON `user_chart` (`title`);
CREATE TABLE `chart_view` (
    `id`        BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `user_id`   BIGINT NOT NULL DEFAULT 1,
    `public`    CHAR(1) DEFAULT 0,
    `alias`     VARCHAR(200) DEFAULT 'n/a',
    `options`   TEXT,
    FOREIGN KEY (`user_id`) REFERENCES `user`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `chart_view_alias_index` ON `chart_view` (`alias`);
CREATE TABLE `service_parameter` (
    `ref_id`                    BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `host_template_id`          BIGINT NULL,
    `agent_id`                  VARCHAR(100) NOT NULL DEFAULT 'localhost',
    `service_name`              VARCHAR(100) NOT NULL,
    `host_alive_check`          CHAR(1) NOT NULL DEFAULT '0',
    `passive_check`             CHAR(1) NOT NULL DEFAULT '0',
    `command_options`           TEXT NOT NULL,
    `location_options`          TEXT NOT NULL,
    `agent_options`             TEXT NOT NULL,
    `sum_services`              SMALLINT NOT NULL DEFAULT '1',
    `plugin_id`                 BIGINT NOT NULL,
    `description`               VARCHAR(100) NOT NULL DEFAULT '',
    `comment`                   VARCHAR(200) NOT NULL DEFAULT '',
    `interval`                  INTEGER NOT NULL DEFAULT 0,
    `retry_interval`            INTEGER NOT NULL DEFAULT 0,
    `timeout`                   INTEGER NOT NULL DEFAULT 0,
    `attempt_warn2crit`         CHAR(1) NOT NULL DEFAULT 0,
    `attempt_max`               SMALLINT NOT NULL DEFAULT 3,
    `notification_interval`     INTEGER NOT NULL DEFAULT 3600,
    `fd_enabled`                CHAR(1) NOT NULL DEFAULT 1,
    `fd_time_range`             INTEGER NOT NULL DEFAULT 1800,
    `fd_flap_count`             INTEGER NOT NULL DEFAULT 8,
    `is_volatile`               CHAR(1) NOT NULL DEFAULT 0,
    FOREIGN KEY (`host_template_id`) REFERENCES `host_template`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`plugin_id`) REFERENCES `plugin`(`id`)
) ENGINE=InnoDB;

CREATE INDEX `service_parameter_ref_id_index` ON `service_parameter` (`ref_id`);
CREATE INDEX `service_parameter_service_name` ON `service_parameter` (`service_name`);
CREATE TABLE `service` (
    `id`                        BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `host_id`                   BIGINT NOT NULL,
    `service_parameter_id`      BIGINT NOT NULL,
    `active`                    CHAR(1) NOT NULL DEFAULT 1,
    `acknowledged`              CHAR(1) NOT NULL DEFAULT 0,
    `notification`              CHAR(1) NOT NULL DEFAULT 1,
    `agent_version`             VARCHAR(10) NOT NULL DEFAULT '0',
    `subkeys`                   TEXT,
    `active_comment`            VARCHAR(400) DEFAULT 'no comment',
    `acknowledged_comment`      VARCHAR(400) DEFAULT 'no comment',
    `notification_comment`      VARCHAR(400) DEFAULT 'no comment',
    `volatile_comment`          VARCHAR(400) DEFAULT 'no comment',
    `attempt_counter`           SMALLINT NOT NULL DEFAULT 1,
    `last_notification_1`       BIGINT NOT NULL DEFAULT 0,
    `last_notification_2`       BIGINT NOT NULL DEFAULT 0,
    `last_check`                BIGINT NOT NULL DEFAULT 0,
    `highest_attempt_status`    VARCHAR(10) NOT NULL DEFAULT 'OK',
    `flapping`                  CHAR(1) NOT NULL DEFAULT 0,
    `scheduled`                 CHAR(1) NOT NULL DEFAULT 0,
    `agent_dead`                CHAR(1) NOT NULL DEFAULT 0,
    `next_check`                BIGINT NOT NULL DEFAULT 0,
    `next_timeout`              BIGINT NOT NULL DEFAULT 0,
    `last_event`                BIGINT NOT NULL DEFAULT 0,
    `status_since`              BIGINT NOT NULL DEFAULT 0,
    `status_nok_since`          BIGINT NOT NULL DEFAULT 0,
    `status_dependency_matched` BIGINT NOT NULL DEFAULT 0,
    `volatile_status`           CHAR(1) NOT NULL DEFAULT 0,
    `volatile_since`            BIGINT NOT NULL DEFAULT 0,
    `status`                    VARCHAR(10) NOT NULL DEFAULT 'INFO',
    `result`                    TEXT NULL,
    `debug`                     TEXT NULL,
    `message`                   TEXT NOT NULL,
    `creation_time`             TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `updated`                   CHAR(1) DEFAULT '0',
    `last_status`               VARCHAR(10) DEFAULT 'INFO',
    `force_check`               CHAR(1) DEFAULT '0',
    `force_event`               CHAR(1) DEFAULT '0',
    FOREIGN KEY (`host_id`) REFERENCES `host`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`service_parameter_id`) REFERENCES `service_parameter`(`ref_id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `service_id_index` ON `service` (`id`);
CREATE INDEX `service_host_id_index` ON `service` (`host_id`);
CREATE TABLE `cache` (
    `id`   BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `type` VARCHAR(100) NOT NULL,
    `data` TEXT
) ENGINE=InnoDB;

CREATE INDEX `cache_type_index` ON `cache` (`type`);
CREATE TABLE `location` (
    `id`           BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `ipaddr`       VARCHAR(159) NOT NULL,
    `port`         SMALLINT NOT NULL DEFAULT '5464',
    `hostname`     VARCHAR(50) NOT NULL,
    `city`         VARCHAR(50) NOT NULL,
    `country`      VARCHAR(50) NOT NULL,
    `continent`    VARCHAR(13) NOT NULL,
    `coordinates`  VARCHAR(500) NOT NULL DEFAULT '0,0',
    `description`  VARCHAR(500)
) ENGINE=InnoDB;
CREATE TABLE `dependency` (
    `id`                BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `host_id`           BIGINT,
    `service_id`        BIGINT,
    `status`            VARCHAR(32) NOT NULL DEFAULT 'CRITICAL,UNKNOWN,INFO',
    `on_host_id`        BIGINT,
    `on_service_id`     BIGINT,
    `on_status`         VARCHAR(32) NOT NULL DEFAULT 'CRITICAL,UNKNOWN,INFO',
    `inherit`           CHAR(1) NOT NULL DEFAULT 0,
    `timezone`          VARCHAR(40) NOT NULL DEFAULT 'Europe/Berlin',
    `timeslice`         TEXT,
    UNIQUE(`service_id`, `on_service_id`),
    FOREIGN KEY (`host_id`) REFERENCES `host`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`service_id`) REFERENCES `service`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`on_host_id`) REFERENCES `host`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`on_service_id`) REFERENCES `service`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `dependency_host_id_index` ON `dependency` (`host_id`);
CREATE INDEX `dependency_on_host_id_index` ON `dependency` (`on_host_id`);
CREATE INDEX `dependency_service_id_index` ON `dependency` (`service_id`);
CREATE INDEX `dependency_on_service_id_index` ON `dependency` (`on_service_id`);
CREATE INDEX `dependency_on_status_id_index` ON `dependency` (`on_status`);
CREATE TABLE `contactgroup` (
    `id`            BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `company_id`    BIGINT NOT NULL,
    `name`          VARCHAR(100) NOT NULL,
    `description`   VARCHAR(100),
    `creation_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (`company_id`) REFERENCES `company`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `contact` (
    `id`                            BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `company_id`                    BIGINT NOT NULL,
    `name`                          VARCHAR(100) NOT NULL,
    `escalation_time`               INTEGER NOT NULL DEFAULT '0',
    `creation_time`                 TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (`company_id`) REFERENCES `company`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `contact_message_services` (
    `id`                 BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `contact_id`         BIGINT NOT NULL,
    `message_service`    VARCHAR(20) NOT NULL,
    `enabled`            CHAR(1) NOT NULL DEFAULT 1,
    `send_to`            VARCHAR(100),
    `notification_level` VARCHAR(40) NOT NULL DEFAULT 'all',
    `creation_time`      TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (`contact_id`) REFERENCES `contact`(`id`) ON DELETE CASCADE
)  ENGINE=InnoDB;
CREATE TABLE `contact_contactgroup` (
    `contactgroup_id`   BIGINT NOT NULL,
    `contact_id`        BIGINT NOT NULL,
    UNIQUE (`contactgroup_id`, `contact_id`),
    FOREIGN KEY (`contactgroup_id`) REFERENCES `contactgroup`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`contact_id`) REFERENCES `contact`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `host_contactgroup` (
    `contactgroup_id`   BIGINT NOT NULL,
    `host_id`           BIGINT NOT NULL,
    UNIQUE (`contactgroup_id`, `host_id`),
    FOREIGN KEY (`contactgroup_id`) REFERENCES `contactgroup`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`host_id`) REFERENCES `host`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `service_contactgroup` (
    `contactgroup_id`   BIGINT NOT NULL,
    `service_id`        BIGINT NOT NULL,
    UNIQUE (`contactgroup_id`, `service_id`),
    FOREIGN KEY (`contactgroup_id`) REFERENCES `contactgroup`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`service_id`) REFERENCES `service`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `timeperiod` (
    `id`            BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `company_id`    BIGINT NOT NULL,
    `name`          VARCHAR(40) NOT NULL,
    `description`   VARCHAR(100),
    FOREIGN KEY (`company_id`) REFERENCES `company`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `timeslice` (
    `id`            BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `timeperiod_id` BIGINT NOT NULL,
    `timeslice`     VARCHAR(200) NOT NULL,
    FOREIGN KEY (`timeperiod_id`) REFERENCES `timeperiod`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `contact_timeperiod` (
    `id`                BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `contact_id`        BIGINT NOT NULL,
    `timeperiod_id`     BIGINT NOT NULL,
    `message_service`   VARCHAR(20) NOT NULL DEFAULT 'all',
    `exclude`           CHAR(1) NOT NULL DEFAULT '0',
    `timezone`          VARCHAR(40) NOT NULL DEFAULT 'Europe/Berlin',
    FOREIGN KEY (`contact_id`) REFERENCES `contact`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`timeperiod_id`) REFERENCES `timeperiod`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;
CREATE TABLE `host_downtime` (
    `id`            BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `host_id`       BIGINT NOT NULL,
    `begin`         DATETIME,
    `end`           DATETIME,
    `timeslice`     VARCHAR(200),
    `flag`          VARCHAR(100) DEFAULT 'none',
    `timezone`      VARCHAR(40) NOT NULL DEFAULT 'Europe/Berlin',
    `username`      VARCHAR(50) NOT NULL,
    `description`   VARCHAR(300) NOT NULL,
    FOREIGN KEY (`host_id`) REFERENCES `host`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `host_downtime_index` ON `host_downtime` (`host_id`, `begin`, `end`);
CREATE TABLE `service_downtime` (
    `id`            BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `host_id`       BIGINT NOT NULL,
    `service_id`    BIGINT NOT NULL,
    `begin`         DATETIME,
    `end`           DATETIME,
    `timeslice`     VARCHAR(200),
    `flag`          VARCHAR(100),
    `timezone`      VARCHAR(40) NOT NULL DEFAULT 'Europe/Berlin',
    `username`      VARCHAR(50) NOT NULL,
    `description`   VARCHAR(300) NOT NULL,
    FOREIGN KEY (`host_id`) REFERENCES `host`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`service_id`) REFERENCES `service`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `service_downtime_index` ON `service_downtime` (`host_id`, `begin`, `end`);
CREATE TABLE `notification` (
    `time`              BIGINT DEFAULT 0,
    `host_id`           BIGINT NOT NULL,
    `company_id`        BIGINT NOT NULL DEFAULT 0,
    `message_service`   VARCHAR(20) NOT NULL DEFAULT 'n/a',
    `send_to`           VARCHAR(100) NOT NULL,
    `subject`           VARCHAR(200) NOT NULL,
    `message`           TEXT NOT NULL
) ENGINE=InnoDB;

CREATE INDEX `notification_time_host_id_index` ON `notification` (`time`, `host_id`);
CREATE INDEX `notification_time_company_id_index` ON `notification` (`time`, `company_id`);
CREATE TABLE `user_tracking` (
    `id`            BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    `company_id`    BIGINT NOT NULL,
    `time`          DATETIME NOT NULL,
    `user_id`       BIGINT NOT NULL,
    `username`      VARCHAR(50) NOT NULL,
    `action`        VARCHAR(10) NOT NULL,
    `target`        VARCHAR(200) NOT NULL DEFAULT 'n/a',
    `message`       TEXT NOT NULL,
    FOREIGN KEY (`company_id`) REFERENCES `company`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB;

CREATE INDEX `user_tracking_company_id_index` ON `user_tracking`(`company_id`);
CREATE INDEX `user_tracking_time_index` ON `user_tracking`(`time`);
CREATE TABLE `lock_srvchk` (
    `locked` char(1)
);
CREATE TABLE `maintenance` (
    `version` VARCHAR(10),
    `active` BIGINT NOT NULL DEFAULT 0
) ENGINE=InnoDB;
INSERT INTO `company` (`company`,`variables`) VALUES ('Bloonix','{}');

INSERT INTO `user` (
    `id`, `company_id`, `username`, `manage_contacts`, `manage_templates`,
    `locked`, `role`, `comment`, `name`, `stash`
) VALUES (
    1, 1, 'admin', 1, 1, 0, 'admin', 'Administrator', 'Administrator', '{}'
);

INSERT INTO `user_secret` (
    `user_id`, `crypt_type`, `salt`, `rounds`, `password`
) VALUES (
    '1',
    '1',
    'H23QZ5c2tBYijITNoz409NNpMr9GiHhF4uE3adX4FyExT6UjWRonye54mSvyOo8V',
    '17775',
    'TYSZ8HM+o8xU05wviSwQUI1avoS816ftBuUy+cxo4n0B3L3SXOC79fARCw2E/Q/2+A9PYgu7MTy3JfluFJS9KA=='
);

INSERT INTO `group` (
    `id`, `company_id`, `groupname`, `description`
) VALUES (
    1, 1, 'Administrator', 'Administration'
);

INSERT INTO `user_group` (
    `user_id`, `group_id`, `create_service`, `update_service`, `delete_service`,
    `create_host`, `update_host`, `delete_host`
) VALUES (
    1, 1, 1, 1, 1, 1, 1, 1
);

INSERT INTO `status_priority` (`priority`, `status`) VALUES (0, 'OK');
INSERT INTO `status_priority` (`priority`, `status`) VALUES (5, 'INFO');
INSERT INTO `status_priority` (`priority`, `status`) VALUES (10, 'WARNING');
INSERT INTO `status_priority` (`priority`, `status`) VALUES (20, 'CRITICAL');
INSERT INTO `status_priority` (`priority`, `status`) VALUES (30, 'UNKNOWN');

insert into `timeperiod` (`company_id`, `name`, `description`)
values (1, '24x7', 'Around the clock');

insert into `timeslice` (`timeperiod_id`, `timeslice`)
values (1, 'Monday - Sunday 00:00 - 23:59');

insert into `timeperiod` (`company_id`, `name`, `description`)
values (1, 'Working time', 'Monday to friday from 9-17');

insert into `timeslice` (`timeperiod_id`, `timeslice`)
values (2, 'Monday - Friday 09:00 - 17:00');

insert into `timeperiod` (`company_id`, `name`, `description`)
values (1, 'Off time', 'The opposite of the working time');

insert into `timeslice` (`timeperiod_id`, `timeslice`)
values (3, 'Monday - Friday 17:01 - 23:59'),
       (3, 'Monday - Friday 00:00 - 08:59'),
       (3, 'Saturday - Sunday 00:00 - 23:59');

INSERT INTO `maintenance` (`version`, `active`) values ('-1', '0');
